==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/smug/kipiplugin_smug.desktop.cmake <==
[Desktop Entry]
Name=SmugMug Import/Export
Name[ast]=Importar/esportar SmugMug
Name[bg]=Внасяне и изнасяне от и към SmugMug
Name[ca]=Importador/Exportador a SmugMug
Name[ca@valencia]=SmugMug Import/Export
Name[cs]=SmugMug Import/Export
Name[da]=SmugMug import/eksport
Name[de]=SmugMug-Import/Export
Name[el]=Εισαγωγέας/εξαγωγέας SmugMug
Name[en_GB]=SmugMug Import/Export
Name[es]=Importar/Exportar a SmugMug
Name[et]=SmugMugi import/eksport
Name[eu]=SmugMug inportatzea/esportatzea
Name[fr]=Importation/exportation SmugMug
Name[ga]=Iompórtáil/Easpórtáil SmugMug
Name[gl]=Importación/Exportación a SmugMug
Name[hu]=SmugMug importálós/exportálás
Name[is]=SmugMug inn/útflutningur
Name[it]=Importazione ed esportazione a SmugMug
Name[ja]=SmugMug Import/Export
Name[km]=នាំចូល/នាំចេញ SmugMug
Name[lv]=Importēt no/Eksportēt uz SmugMug
Name[nb]=SmugMug-import/eksport
Name[nds]=SmugMug-Im- un Exporteren
Name[nl]=SmugMug-importeren/exporteren
Name[pa]=ਸਮੱਗਮੱਗ ਇੰਪੋਰਟ/ਐਕਸਪੋਰਟ
Name[pl]=Import/Eksport SmugMug
Name[pt]=Importação/Exportação para o SmugMug
Name[pt_BR]=Exportar/importar para o SmugMug
Name[ro]=Import/Export SmugMug
Name[ru]=Импорт и экспорт в SmugMug
Name[sk]=SmugMug import a export
Name[sl]=Uvoz/izvoz iz/v SmugMug
Name[sq]=SmugMug Import/Export
Name[sv]=SmugMug import och export
Name[th]=นำเข้า/ส่งออก ไปยังบริการ SmugMug
Name[tr]=SmugMug İçeriye/Dışarıya Aktar
Name[uk]=Інструмент імпорту/експорту до SmugMug
Name[x-test]=xxSmugMug Import/Exportxx
Name[zh_CN]=SmugMug 导入/导出
Name[zh_TW]=SmugMug 匯入/匯出
Comment=A tool to import/export images to/from a remote SmugMug web service
Comment[ast]=Una ferramienta pa importar/esportar imáxenes pa/dende'l serviciu web remotu de SmugMug
Comment[bg]=Инструмент за внасяне и изнасяне на изображения от и към отдалечена уеб-услуга SmugMug
Comment[ca]=Una eina per importar/exportar imatges a un servei web remot SmugMug
Comment[ca@valencia]=Una eina per importar/exportar imatges a un servei web remot SmugMug
Comment[cs]=Nástroj pro import/export obrázků z/do webové služby SmugMug
Comment[da]=Et værktøj til at importere/eksportere billeder fra/til en ekstern SmugMug-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu/von einem SmugMug-Webdienst zu ex-/importieren.
Comment[el]=Εργαλείο για την εισαγωγή/εξαγωγή εικόνων σε/προς μια απομακρυσμένη υπηρεσία ιστού SmugMug
Comment[en_GB]=A tool to import/export images to/from a remote SmugMug web service
Comment[es]=Una herramienta para exportar las imágenes al servicio web remoto de SmugMug
Comment[et]=Tööriist piltide importimiseks/eksportimiseks SmugMugi veebiteenusest/veebiteenusesse
Comment[eu]=Urruneko SmugMug web zerbitzutik irudiak inportatzeko/esportatzeko tresna
Comment[fr]=Outil pour importer/exporter les images depuis/vers le service en ligne SmugMug
Comment[ga]=Uirlis a iompórtálann/easpórtálann íomhánna ó/go seirbhís Ghréasáin SmugMug
Comment[gl]=Unha ferramenta para importar ou exportar imaxes a un servizo web SmugMug remoto
Comment[hu]=Egy eszköz képek importálásához/exportálásához egy távoli SmugMug webszolgáltatáshoz
Comment[is]=Verkfæri til að senda/flytja inn myndir frá fjarlæga SmugMug vefþjónustu
Comment[it]=Uno strumento per importare ed esportare immagini da e al servizio Web SmugMug
Comment[ja]=画像を SmugMug ウェブサービスにエクスポート/からインポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចូល/នាំចេញ​រូបភាព​ទៅ​/ពី​សេវា​បណ្ដាញ SmugMug ពីចម្ងាយ
Comment[lv]=Rīks attēlu importēšanai no/eksportēšanai uz attālināto SmugMug tīmekļa servisu
Comment[nb]=Et verktøy for å importere/eksportere bilder til/fra en fjern SmugMug-nettjeneste
Comment[nds]=En Warktüüch, mit dat sik Biller vun oder na en SmugMug-Nettdeenst im- oder exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen naar/van een SmugMug-webservice te ex/importeren
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਰਿਮੋਟ SmugMug ਵੈੱਬ ਸਰਵਿਸ ਉੱਤੇ ਇੰਪੋਰਟ/ਐਕਸਪੋਰਟ ਕਰਨ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do importowania/eksportowania obrazów z/do zdalnej usługi sieciowej SmugMug
Comment[pt]=Uma ferramenta para importar/exportar imagens para o serviço Web remoto do SmugMug
Comment[pt_BR]=Uma ferramenta para exportar/importar imagens para um serviço da Internet remoto SmugMug
Comment[ro]=O unealtă de importat/exportat imagini din/pe serviciul web SmugMug
Comment[ru]=Инструмент для импорта и экспорта изображений в веб-службу SmugMug
Comment[sk]=Nástroj na import a export obrázkov z a do SmugMug
Comment[sl]=Orodje za uvoz/izvoz slik iz/v oddaljeno spletno storitev SmugMug
Comment[sq]=Një mjet për të importuar/eksportuar imazhet nga/tek shërbimi i internetit SmugMug
Comment[sv]=Ett verktyg för att exportera bilder till och importera bilder från en SmugMug fjärrwebbtjänst
Comment[th]=เครื่องมือในการนำเข้า/ส่งออกภาพ จาก/ไปยัง เว็บบริการ SmugMug
Comment[tr]=Resimleri uzak bir SmugMug web servisine aktarmak  ve oradan almak için bir araç
Comment[uk]=Інструмент для імпорту/експорту зображень до віддаленої служби SmugMug
Comment[x-test]=xxA tool to import/export images to/from a remote SmugMug web servicexx
Comment[zh_CN]=一个将图像从 SmugMug 网络服务导入/导出到 SmugMug 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 SmugMug 網頁服務/從遠端 SmugMug 網頁服務匯入影像的工具
Type=Service
Icon=smugmug
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_smug
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Luka Renko, lure@kubuntu.org

==> digikam_3.5.0.orig.tar.bz2: digikam-3.5.0/extra/kipi-plugins/smug/kipiplugin_smug.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=SmugMug Import/Export
Name=SmugMug Import/Export
Name[ast]=Importar/esportar SmugMug
Name[bg]=Внасяне и изнасяне от и към SmugMug
Name[bs]=SmugMug Uzvoz/Izvoz
Name[ca]=Importador/Exportador a SmugMug
Name[ca@valencia]=Importador/Exportador a SmugMug
Name[cs]=SmugMug Import/Export
Name[da]=SmugMug import/eksport
Name[de]=SmugMug-Import/Export
Name[el]=Εισαγωγέας/εξαγωγέας SmugMug
Name[en_GB]=SmugMug Import/Export
Name[es]=Importar/Exportar a SmugMug
Name[et]=SmugMugi import/eksport
Name[eu]=SmugMug inportatzea/esportatzea
Name[fr]=Importation / exportation « SmugMug »
Name[ga]=Iompórtáil/Easpórtáil SmugMug
Name[gl]=Importación/Exportación a SmugMug
Name[hu]=SmugMug importálós/exportálás
Name[is]=SmugMug inn/útflutningur
Name[it]=Importazione ed esportazione a SmugMug
Name[ja]=SmugMug Import/Export
Name[km]=នាំចូល/នាំចេញ SmugMug
Name[lv]=Importēt no/Eksportēt uz SmugMug
Name[nb]=SmugMug-import/eksport
Name[nds]=SmugMug-Im- un Exporteren
Name[nl]=SmugMug-importeren/exporteren
Name[pa]=ਸਮੱਗਮੱਗ ਇੰਪੋਰਟ/ਐਕਸਪੋਰਟ
Name[pl]=Import/Eksport SmugMug
Name[pt]=Importação/Exportação para o SmugMug
Name[pt_BR]=Exportar/importar para o SmugMug
Name[ro]=Import/Export SmugMug
Name[ru]=Импорт и экспорт в SmugMug
Name[sk]=SmugMug import a export
Name[sl]=Uvoz/izvoz iz/v SmugMug
Name[sq]=SmugMug Import/Export
Name[sv]=SmugMug import och export
Name[th]=นำเข้า/ส่งออก ไปยังบริการ SmugMug
Name[tr]=SmugMug İçeriye/Dışarıya Aktar
Name[uk]=Інструмент імпорту/експорту до SmugMug
Name[x-test]=xxSmugMug Import/Exportxx
Name[zh_CN]=SmugMug 导入/导出
Name[zh_TW]=SmugMug 匯入/匯出
Comment=A tool to import/export images to/from a remote SmugMug web service
Comment[ast]=Una ferramienta pa importar/esportar imáxenes pa/dende'l serviciu web remotu de SmugMug
Comment[bg]=Инструмент за внасяне и изнасяне на изображения от и към отдалечена уеб-услуга SmugMug
Comment[bs]=Alat za uvoz/izvoz slika na/iz udaljeni/udaljenog SmugMug web servisa
Comment[ca]=Una eina per importar/exportar imatges a un servei web remot SmugMug
Comment[ca@valencia]=Una eina per importar/exportar imatges a un servei web remot SmugMug
Comment[cs]=Nástroj pro import/export obrázků z/do webové služby SmugMug
Comment[da]=Et værktøj til at importere/eksportere billeder fra/til en ekstern SmugMug-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu/von einem SmugMug-Webdienst zu ex-/importieren.
Comment[el]=Εργαλείο για την εισαγωγή/εξαγωγή εικόνων σε/προς μια απομακρυσμένη υπηρεσία ιστού SmugMug
Comment[en_GB]=A tool to import/export images to/from a remote SmugMug web service
Comment[es]=Una herramienta para exportar las imágenes al servicio web remoto de SmugMug
Comment[et]=Tööriist piltide importimiseks/eksportimiseks SmugMugi veebiteenusest/veebiteenusesse
Comment[eu]=Urruneko SmugMug web zerbitzutik irudiak inportatzeko/esportatzeko tresna
Comment[fr]=Un outil d'importation / exportation d'images depuis / vers le service en ligne « SmugMug »
Comment[ga]=Uirlis a iompórtálann/easpórtálann íomhánna ó/go seirbhís Ghréasáin SmugMug
Comment[gl]=Unha ferramenta para importar ou exportar imaxes a un servizo web SmugMug remoto
Comment[hu]=Egy eszköz képek importálásához/exportálásához egy távoli SmugMug webszolgáltatáshoz
Comment[is]=Verkfæri til að senda/flytja inn myndir frá fjarlæga SmugMug vefþjónustu
Comment[it]=Uno strumento per importare ed esportare immagini da e al servizio Web SmugMug
Comment[ja]=画像を SmugMug ウェブサービスにエクスポート/からインポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចូល/នាំចេញ​រូបភាព​ទៅ​/ពី​សេវា​បណ្ដាញ SmugMug ពីចម្ងាយ
Comment[lv]=Rīks attēlu importēšanai no/eksportēšanai uz attālināto SmugMug tīmekļa servisu
Comment[nb]=Et verktøy for å importere/eksportere bilder til/fra en fjern SmugMug-nettjeneste
Comment[nds]=En Warktüüch, mit dat sik Biller vun oder na en SmugMug-Nettdeenst im- oder exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen naar/van een SmugMug-webservice te ex/importeren
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਰਿਮੋਟ SmugMug ਵੈੱਬ ਸਰਵਿਸ ਉੱਤੇ ਇੰਪੋਰਟ/ਐਕਸਪੋਰਟ ਕਰਨ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do importowania/eksportowania obrazów z/do zdalnej usługi sieciowej SmugMug
Comment[pt]=Uma ferramenta para importar/exportar imagens para o serviço Web remoto do SmugMug
Comment[pt_BR]=Uma ferramenta para exportar/importar imagens para um serviço da Internet remoto SmugMug
Comment[ro]=O unealtă de importat/exportat imagini din/pe serviciul web SmugMug
Comment[ru]=Инструмент для импорта и экспорта изображений в веб-службу SmugMug
Comment[sk]=Nástroj na import a export obrázkov z a do SmugMug
Comment[sl]=Orodje za uvoz/izvoz slik iz/v oddaljeno spletno storitev SmugMug
Comment[sq]=Një mjet për të importuar/eksportuar imazhet nga/tek shërbimi i internetit SmugMug
Comment[sv]=Ett verktyg för att exportera bilder till och importera bilder från en SmugMug fjärrwebbtjänst
Comment[th]=เครื่องมือในการนำเข้า/ส่งออกภาพ จาก/ไปยัง เว็บบริการ SmugMug
Comment[tr]=Resimleri uzak bir SmugMug web servisine aktarmak  ve oradan almak için bir araç
Comment[uk]=Інструмент для імпорту/експорту зображень до віддаленої служби SmugMug
Comment[x-test]=xxA tool to import/export images to/from a remote SmugMug web servicexx
Comment[zh_CN]=一个将图像从 SmugMug 网络服务导入/导出到 SmugMug 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 SmugMug 網頁服務/從遠端 SmugMug 網頁服務匯入影像的工具
Type=Service
Icon=kipi-smugmug
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_smug
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Luka Renko, lure@kubuntu.org
